#!/bin/bash

brisa_install='usr/lib/python2.5/site-packages/brisa/'
bin_base='usr/bin'

debian='DEBIAN'
tmp='/tmp/brisa_packages'
version='0.7'
ARCH="all"

cd ..
python2.5 setup.py clean
rm -rf build/ dist/ brisa.egg-info/
 
python2.5 -OO setup.py install --root dist_deb/

root_dir=`pwd`

cd dist_deb

rm -rf $tmp

mkdir -p $tmp
cp -a base_conf/brisa* $tmp
cd $brisa_install

create_pack(){

	deb_dir=$tmp/$name/$debian
	inst_dir=$tmp/$name/$brisa_install

	mkdir -p $deb_dir
	mkdir -p $inst_dir
	for item in $list
	do
		cp -av --parents  ${item} $inst_dir
	done

	clean_dirs
}

remove_files(){
	echo "removing files"
	for item in $list
	do
		removed=$tmp/$name/$brisa_install$item
		rm -rvf $removed
	done

}

clean_dirs(){
	rm_dir=$tmp/$name
	find $rm_dir -name "\.svn" | xargs rm -rf 
	rm -rfv `find $rm_dir -name \*.py`
	#rm -rfv `find $rm_dir -name \*.pyc`
}

replace_attr(){
	TEMPFILE=/tmp/replaceZZ.tmp

	if test $# -lt 3; then
		echo Usage $0 replace_this with_this files
		exit 1
	fi

	#get the replacement and text to replace
	replacethis=$1 #the first argument
	withthis=$2 #the second argument
	shift 2

	for file ; do
		nummatches=`grep $replacethis $file | wc -l | sed -e "s/ //g"`
		if test $nummatches -eq 0; then
			echo $file: 0 occurrences
		else
			echo $file: replacing $nummatches occurrences
			sed -e "s+$replacethis+$withthis+g" $file > $TEMPFILE
			mv $TEMPFILE $file
		fi
	done
}

copy_executables(){
	bin_dest=$tmp/$name/$bin_base
	mkdir -p $bin_dest
	for file in $list_exec
	do
		cp $file $bin_dest
	done
}

create_deb_conf(){
	deb_file=$tmp/$name/$debian/control
	du_dir=$tmp/$name

	length=`du -s $du_dir`
	echo $deb_file
	echo $length

	replace_attr xxxxx $length $deb_file
        replace_attr vvvvv $version $deb_file
        replace_attr ARCH $ARCH $deb_file
}

echo "Building brisa"

name="brisa"
create_deb_conf

echo "Building brisa-base"

name="brisa-base"
list="brisa.conf config/ logging/ utils/ documentation/ __init__.pyc upnp/ devices/__init__.pyc services/__init__.pyc services/web_server/ xml_descriptions/__init__.pyc"

create_pack
create_deb_conf

echo "Building brisa-control-point"

name="brisa-control-point"
list="control_point/"

create_pack
list="control_point/gui"
remove_files
create_deb_conf

echo "Building brisa-control-point-gui"

name="brisa-control-point-gui"
list="control_point/gui"
list_exec='../../../../bin/brisa-control-point'

create_pack
copy_executables
create_deb_conf

echo "Building brisa-media-renderer"

name="brisa-media-renderer"
list="devices/media_renderer/ services/render_control/ services/avtransport/ xml_descriptions/renderconnmgrSCPD.xml xml_descriptions/rendercontrolSCPD.xml xml_descriptions/rendertransportSCPD.xml services/gst_renderer/"
list_exec='../../../../bin/brisa-renderer'

create_pack
copy_executables
create_deb_conf

echo "Building brisa-media-server-baseplugins"

name="brisa-media-server-baseplugins"
list="services/cds/plugins/filesystem services/cds/plugins"
create_pack
create_deb_conf

echo "Building brisa-media-server"

name="brisa-media-server"
list="services/cds/ services/connmgr devices/media_server/ xml_descriptions/connection-manager-scpd.xml xml_descriptions/content-directory-scpd.xml xml_descriptions/media-receiver-registrar-ms.xml services/media_registrar_ms/"
list_exec='../../../../bin/brisa-server'

create_pack
list="services/cds/plugins/"
remove_files
copy_executables
create_deb_conf

echo "Building brisa-manager"

name="brisa-webmanager"
list="config_web/"
list_exec="../../../../bin/brisa-conf ../../../../bin/brisa-web"

create_pack
copy_executables
create_deb_conf

name="brisa-localconf"
list="config_gtk/"
list_exec="../../../../bin/brisa-localconf ../../../../bin/brisa-tray"

create_pack
copy_executables
create_deb_conf


echo "Erasing temporary files"
cd $root_dir
python2.5 setup.py clean
rm -rf build/ dist/ brisa.egg-info/ dist_deb/usr/

echo "build finnished"
echo "Now run the create_debs.sh script"

